<template>
  <AdminLayout>
    <DashboardHeader>
      <DashboardTitle>{{ $t("app.admin.analytics.title") }}</DashboardTitle>
      <div>
        <FormDate
          v-model="filters.date"
          name="date"
          range
          required
        />
      </div>
    </DashboardHeader>
    <DashboardBody container>
      <div class="grid grid-cols-1 gap-5 sm:grid-cols-2 xl:grid-cols-4">
        <DashboardSimpleStats
          :icon="LinkRegularIcon"
          :is-loading="totalsFetch.isFetching"
          :value="totals.links"
          label="app.links.title"
        />
        <DashboardSimpleStats
          :icon="ArrowPointerRegularIcon"
          :is-loading="totalsFetch.isFetching"
          :value="totals.link_visits"
          label="app.links.visit.title"
        />
        <DashboardSimpleStats
          :icon="UserGroupRegularIcon"
          :is-loading="totalsFetch.isFetching"
          :value="totals.users"
          label="app.admin.users.title"
        />
        <DashboardSimpleStats
          :icon="GlobeRegularIcon"
          :is-loading="totalsFetch.isFetching"
          :value="totals.domains"
          label="app.admin.domains.title"
        />
      </div>
      <div class="sm:col-span-2 xl:col-span-4">
        <LinksAnalyticsCharts
          :filters="filters"
          is-admin
        />
      </div>
    </DashboardBody>
  </AdminLayout>
</template>

<script lang="ts" setup>
import LinkRegularIcon from "@/svg/icons/link-regular.svg?component";
import ArrowPointerRegularIcon from "@/svg/icons/arrow-pointer-regular.svg?component";
import GlobeRegularIcon from "@/svg/icons/globe-regular.svg?component";
import AdminLayout from "@/js/contexts/admin/shared/ui/layouts/AdminLayout.vue";
import DashboardHeader from "@/js/contexts/shared/ui/components/dashboard/DashboardHeader.vue";
import DashboardBody from "@/js/contexts/shared/ui/components/dashboard/DashboardBody.vue";
import DashboardTitle from "@/js/contexts/shared/ui/components/dashboard/DashboardTitle.vue";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import DashboardSimpleStats from "@/js/contexts/admin/analytics/ui/components/DashboardSimpleStats.vue";
import UserGroupRegularIcon from "@/svg/icons/user-group-regular.svg?component";
import dayjs from "dayjs";
import useFilters from "@/js/contexts/shared/composables/useFilters";
import type { LinkAnalyticsFilters } from "@/js/contexts/links/models/LinkAnalyticsFilters";
import LinksAnalyticsCharts from "@/js/contexts/links/ui/components/LinksAnalyticsCharts.vue";
import FormDate from "@/js/contexts/form/ui/components/FormDate.vue";

const { t } = useI18n();

useHead({
  title: t("app.admin.analytics.title"),
});

const totalsFetch = useFetch("/api/admin/dashboard/totals");

const totals = reactive({ users: 0, user_roles: 0, links: 0, link_visits: 0, domains: 0 });
const filters = useFilters<LinkAnalyticsFilters>(
  {
    date: { start: dayjs().subtract(6, "days").startOf("day").toDate(), end: dayjs().endOf("day").toDate() },
  },
  ["date"],
);

onMounted(() => {
  totalsFetch.get<{ links: number; link_visits: number; users: number; domains: number }>().then((response) => {
    totals.links = response.data.links;
    totals.link_visits = response.data.link_visits;
    totals.users = response.data.users;
    totals.domains = response.data.domains;
  });
});
</script>
